@@ -13,39 +13,54 @@ class Apps:
         self.saagie_api = saagie_api
         self.client = saagie_api.client
 
-    def list_for_project(self, project_id: str) -> Dict:
+    def list_for_project(
+        self, project_id: str, instances_limit: int = None, pprint_result: Optional[bool] = None
+    ) -> Dict:
         """List apps of project.
         NB: You can only list apps if you have at least the viewer role on
         the project.
+
         Parameters
         ----------
         project_id : str
             UUID of your project (see README on how to find it)
+        instances_limit: int
+            limit the number of instances to return, default to no limit
+        pprint_result : bool, optional
+            Whether to pretty print the result of the query, default to
+            saagie_api.pprint_global
 
         Returns
         -------
         dict
             Dict of app information
         """
+        params = {"projectId": project_id, "instancesLimit": instances_limit}
         return self.saagie_api.client.execute(
-            query=gql(GQL_LIST_APPS_FOR_PROJECT), variable_values={"id": project_id}, pprint_result=True
+            query=gql(GQL_LIST_APPS_FOR_PROJECT), variable_values={"id": project_id}, pprint_result=pprint_result
         )
 
-    def get_info(self, app_id: str, pprint_result: Optional[bool] = True) -> Dict:
+    def get_info(self, app_id: str, instances_limit: int = None, pprint_result: Optional[bool] = None) -> Dict:
         """Get app with given UUID.
+
         Parameters
         ----------
         app_id : str
             UUID of your app
-        pprint_result : str
-            Whether to pretty print the results in the console or not
+        pprint_result : bool, optional
+            Whether to pretty print the result of the query, default to
+            saagie_api.pprint_global
+        instances_limit: int
+            limit the number of instances to return, default to no limit
+
         Returns
         -------
         dict
             Dict of app information
         """
+        params = {"id": app_id, "instancesLimit": instances_limit}
         return self.saagie_api.client.execute(
-            query=gql(GQL_GET_APP_INFO), variable_values={"id": app_id}, pprint_result=pprint_result
+            query=gql(GQL_GET_APP_INFO), variable_values=params, pprint_result=pprint_result
         )
 
     def create_from_scratch(
@@ -305,7 +320,7 @@ class Apps:
             Dict of app information
         """
         params = {"id": app_id}
-        previous_app_version = self.get_info(app_id, pprint_result=False)["labWebApp"]
+        previous_app_version = self.get_info(app_id, instances_limit=1, pprint_result=False)["labWebApp"]
 
         if app_name:
             params["name"] = app_name
